@@ -9,5 +9,5 @@ require "mocha/setup"
 
 Minitest::Reporters.use! Minitest::Reporters::DefaultReporter.new(color: true)
 
-$LOAD_PATH.unshift File.expand_path("../../lib", __FILE__)
+$LOAD_PATH.unshift File.expand_path("../lib", __dir__)
 require "public_suffix"
